pub enum Basis {
Time(Timeframe),
Tick(TickCount),
}Expand description
Defines how chart data is aggregated and displayed along the x-axis.
Variants
Time(Timeframe)
Time-based aggregation where each datapoint represents a fixed time interval.
Tick(TickCount)
Trade-based aggregation where each datapoint represents a fixed number of trades.
The u16 value represents the number of trades per aggregation unit.
Implementations
Sourceimpl Basis
impl Basis
pub fn is_time(&self) -> bool
pub fn default_kline_time( ticker_info: Option<TickerInfo>, fallback: Timeframe, ) -> Self
pub fn default_heatmap_time(ticker_info: Option<TickerInfo>) -> Self