ClusterScaling

Enum ClusterScaling 

pub enum ClusterScaling {
    VisibleRange,
    Hybrid {
        weight: f32,
    },
    Datapoint,
}

Variants



VisibleRange

Scale based on the maximum quantity in the visible range.



Hybrid

Blend global VisibleRange and per-cluster Individual using a weight in [0.0, 1.0]. weight = fraction of global contribution (1.0 == all-global, 0.0 == all-individual).

Fields

weight: f32


Datapoint

Scale based only on the maximum quantity inside the datapoint (per-candle).

Implementations