pub struct KlineTrades {
pub trades: FxHashMap<Price, GroupedTrades>,
pub poc: Option<PointOfControl>,
}Fields
trades: FxHashMap<Price, GroupedTrades>poc: Option<PointOfControl>Implementations
Sourceimpl KlineTrades
impl KlineTrades
pub fn new() -> Self
pub fn first_trade_t(&self) -> Option<u64>
pub fn last_trade_t(&self) -> Option<u64>
Sourcepub fn add_trade_to_side_bin(&mut self, trade: &Trade, step: PriceStep)
pub fn add_trade_to_side_bin(&mut self, trade: &Trade, step: PriceStep)
Add trade to the bin at the step multiple computed with side-based rounding. Intended for order-book ladder/quotes; Floor for sells, ceil for buys. Introduces side bias at bin edges and should not be used for OHLC/footprint aggregation
Sourcepub fn add_trade_to_nearest_bin(&mut self, trade: &Trade, step: PriceStep)
pub fn add_trade_to_nearest_bin(&mut self, trade: &Trade, step: PriceStep)
Add trade to the bin at the nearest step multiple (side-agnostic). Ties (exactly half a step) round up to the higher multiple. Intended for footprint/OHLC trade aggregation
pub fn max_qty_by<F>(&self, highest: Price, lowest: Price, f: F) -> Qty
pub fn max_cluster_qty( &self, cluster_kind: ClusterKind, highest: Price, lowest: Price, ) -> Qty
pub fn calculate_poc(&mut self)
pub fn set_poc_status(&mut self, status: NPoc)
pub fn poc_price(&self) -> Option<Price>
pub fn clear(&mut self)